###################################################
### chunk number 1: 
###################################################
library(lattice)
library(xtable)
library(randomLCA)
data(dentistry)
load("dentistry.lca2.outcomes.boot.RData")
load("dentistry.lca2random.outcomes.boot.RData")
set.seed(12345)
options(width=60)


###################################################
### chunk number 2: 
###################################################
myocardial.lca1 <- randomLCA(myocardial[,1:4],
	freq=myocardial$freq,nclass=1)
myocardial.lca2 <- randomLCA(myocardial[,1:4],
	freq=myocardial$freq,nclass=2,calcSE=TRUE)
myocardial.lca3 <- randomLCA(myocardial[,1:4],
	freq=myocardial$freq,nclass=3)


###################################################
### chunk number 3: 
###################################################
bic.data <- data.frame(classes=1:3,bic=c(BIC(myocardial.lca1),
	BIC(myocardial.lca2),BIC(myocardial.lca3)))


###################################################
### chunk number 4: 
###################################################
print(xtable(bic.data, digits = c(0,0,1),caption="BIC by class.",
	label="tab:bic1"),include.rownames=FALSE)


###################################################
### chunk number 5: 
###################################################
summary(myocardial.lca2)


###################################################
### chunk number 6: 
###################################################
outcomep.data <- summary(myocardial.lca2)$outcomep


###################################################
### chunk number 7: 
###################################################
print(xtable(outcomep.data, digits = c(0,3,3,3,3),caption="Outcome Probabilities.",
	label="tab:outcomep1"))


###################################################
### chunk number 8: 
###################################################
classprobs <- cbind(myocardial.lca2$patterns,myocardial.lca2$classprob)
colnames(classprobs) <- c(names(myocardial)[1:4],"Class 1","Class 2")


###################################################
### chunk number 9: 
###################################################
print(xtable(classprobs, digits = c(0,0,0,0,0,3,3),caption="Class Probabilities.",
	label="tab:classprob1"),include.rownames=FALSE)


###################################################
### chunk number 10: 
###################################################
trellis.par.set(col.whitebg())
print(plot(myocardial.lca2,type="l",xlab="Test",ylab="Outcome Probability",
	scales=list(x=list(at=1:4,labels=names(myocardial)[1:4]))))


###################################################
### chunk number 11: 
###################################################
dentistry.lca1 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=1)
dentistry.lca2 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=2,calcSE=TRUE)
dentistry.lca3 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=3)
dentistry.lca4 <- randomLCA(dentistry[,1:5],
	freq=dentistry$freq,nclass=4)


###################################################
### chunk number 12: 
###################################################
bic.data <- data.frame(classes=1:4,bic=c(BIC(dentistry.lca1),
	BIC(dentistry.lca2),BIC(dentistry.lca3),BIC(dentistry.lca4)))


###################################################
### chunk number 13: 
###################################################
print(xtable(bic.data, digits = c(0,0,1),caption="BIC by class.",
	label="tab:bic"),include.rownames=FALSE)


###################################################
### chunk number 14: 
###################################################
trellis.par.set(col.whitebg())
print(plot(dentistry.lca3,type="l",xlab="Dentist",ylab="Outcome Probability"))


###################################################
### chunk number 15: 
###################################################
trellis.par.set(col.whitebg())
print(plot(dentistry.lca2,type="l",xlab="Dentist",ylab="Outcome Probability"))


###################################################
### chunk number 16: 
###################################################
outcome.probs(dentistry.lca2)


###################################################
### chunk number 17: 
###################################################
probs <- outcome.probs(dentistry.lca2)
# this swaps around the probabilities based on the knowledge that the undiseased class is more common
order <- ifelse(dentistry.lca2$classp[2]>dentistry.lca2$classp[1],1,2)

spec <- NULL
sens <- NULL
for (i in 1:5) {
	sens <- c(sens,sprintf("%3.2f (%3.2f,%3.2f)",probs[[order]]$Outcome[i],probs[[order]]$"2.5 %"[i],probs[[order]]$"97.5 %"[i]))
	spec <- c(spec,sprintf("%3.2f (%3.2f,%3.2f)",1-probs[[3-order]]$Outcome[i],1-probs[[3-order]]$"97.5 %"[i],1-probs[[3-order]]$"2.5 %"[i]))
}
stable <- data.frame(sens,spec)
names(stable) <- c("Sensitivity","Specificity")
row.names(stable) <- paste("V",1:5,sep="")


###################################################
### chunk number 18: 
###################################################
print(xtable(stable, digits = c(0,2,2),caption="Sensitivity and Specificity",
	label="tab:outcomeconfint"),include.rownames=TRUE)


###################################################
### chunk number 19: 
###################################################
probs <- dentistry.lca2.outcomes.boot
# this swaps around the probabilities based on the knowledge that outcome probabilities are higher in the diseased class
order <- ifelse(probs[[1]]$Outcome[1]>probs[[2]]$Outcome[1],1,2)

spec <- NULL
sens <- NULL
for (i in 1:5) {
	sens <- c(sens,sprintf("%3.2f (%3.2f,%3.2f)",probs[[order]]$Outcome[i],probs[[order]]$"2.5 %"[i],probs[[order]]$"97.5 %"[i]))
	spec <- c(spec,sprintf("%3.2f (%3.2f,%3.2f)",1-probs[[3-order]]$Outcome[i],1-probs[[3-order]]$"97.5 %"[i],1-probs[[3-order]]$"2.5 %"[i]))
}
stable <- data.frame(sens,spec)
names(stable) <- c("Sensitivity","Specificity")
row.names(stable) <- paste("V",1:5,sep="")


###################################################
### chunk number 20: 
###################################################
print(xtable(stable, digits = c(0,2,2),caption="Sensitivity and Specificity",
	label="tab:outcomeconfintboot"),include.rownames=TRUE)


###################################################
### chunk number 21: 
###################################################
itpr <- ifelse(dentistry.lca2$classp[2]>dentistry.lca2$classp[1],1,2)
ifpr <- 3-itpr
probs <- outcome.probs(dentistry.lca2)
probs <- data.frame(tpr=probs[[itpr]][,1],fpr=probs[[ifpr]][,1])


###################################################
### chunk number 22: 
###################################################
trellis.par.set(col.whitebg())
print(plot(tpr~fpr,type="p",xlab="False Positive Rate\n(1-Specificity)",ylab="True Positive Rate (Sensitivity)",data=probs))


###################################################
### chunk number 23: 
###################################################
dentistry.lca2random <- randomLCA(dentistry[,1:5],freq=dentistry$freq,
	initmodel=dentistry.lca2,nclass=2,random=TRUE,quadpoints=31,probit=TRUE)


###################################################
### chunk number 24: 
###################################################
dentistry.lca2random1 <- randomLCA(dentistry[,1:5],freq=dentistry$freq,
	initmodel=dentistry.lca2random,nclass=2,random=TRUE,probit=TRUE,
	quadpoints=31,blocksize=5)


###################################################
### chunk number 25: 
###################################################
dentistry.lca2random2 <- randomLCA(dentistry[,1:5],freq=dentistry$freq,
	initmodel=dentistry.lca2random1,nclass=2,random=TRUE,probit=TRUE,
	blocksize=5,byclass=TRUE,quadpoints=41)


###################################################
### chunk number 26: 
###################################################
trellis.par.set(col.whitebg())
print(plot(dentistry.lca2random1,graphtype="marginal",type="l",xlab="Dentist",ylab="Marginal Outcome Probability"))


###################################################
### chunk number 27: 
###################################################
probs <-dentistry.lca2random.outcomes.boot
# this swaps around the probabilities based on the knowledge that outcome probabilities are higher in the diseased class
order <- ifelse(probs[[1]]$Outcome[1]>probs[[2]]$Outcome[1],1,2)

spec <- NULL
sens <- NULL
for (i in 1:5) {
	sens <- c(sens,sprintf("%3.2f (%3.2f,%3.2f)",probs[[order]]$Outcome[i],probs[[order]]$"2.5 %"[i],probs[[order]]$"97.5 %"[i]))
	spec <- c(spec,sprintf("%3.2f (%3.2f,%3.2f)",1-probs[[3-order]]$Outcome[i],1-probs[[3-order]]$"97.5 %"[i],1-probs[[3-order]]$"2.5 %"[i]))
}
stable <- data.frame(sens,spec)
names(stable) <- c("Sensitivity","Specificity")
row.names(stable) <- paste("V",1:5,sep="")


###################################################
### chunk number 28: 
###################################################
print(xtable(stable, digits = c(0,2,2),caption="Sensitivity and Specificity",
	label="tab:outcomeconfintboot2"),include.rownames=TRUE)


###################################################
### chunk number 29: 
###################################################
obs.data <- data.frame(dentistry.lca2random1$patterns,dentistry.lca2random1$observed,
	dentistry.lca2$fitted,dentistry.lca2random1$fitted)
names(obs.data) <- c("V1","V2","V3","V4","V5","Obs","Exp 2LC","Exp 2LCR")


###################################################
### chunk number 30: 
###################################################
print(xtable(obs.data, caption="Observed and expected frequencies",
	digits = c(0,rep(0,5),0,1,1),label="tab:obs"),include.rownames=FALSE)


